package com.akamai.osmf.samples.view
{
	import flash.display.DisplayObject;
	import flash.display.Shape;
	import flash.display.Sprite;
	import flash.events.Event;
	
	import org.openvideoplayer.components.ui.controlbar.ControlBar;
	import org.openvideoplayer.components.ui.controlbar.view.DualTimeCodeDisplay;
	import org.openvideoplayer.components.ui.controlbar.view.FullscreenButton;
	import org.openvideoplayer.components.ui.controlbar.view.GoLiveButton;
	import org.openvideoplayer.components.ui.controlbar.view.PlayPauseButton;
	import org.openvideoplayer.components.ui.controlbar.view.ScrubBar;
	import org.openvideoplayer.components.ui.controlbar.view.VolumeControl;
	import org.openvideoplayer.components.ui.debug.DebugPanelView;
	import org.openvideoplayer.components.ui.posterframe.PosterFramePlayButton;
	import org.openvideoplayer.components.ui.spinner.SpinnerView;
	import org.osmf.layout.ScaleMode;
	import org.osmf.media.MediaPlayerSprite;
	
	public class BaseVideoView extends Sprite
	{
		private var dummyGoLiveButton:GoLiveButton;	// Force this class to be included in the swc to simplify dependencies for sample projects

		private var _mediaPlayerSprite:MediaPlayerSprite;
		private var _controlBar:ControlBar;
		private var _posterFrameButton:PosterFramePlayButton;
		private var _spinnerView:SpinnerView;
		private var _console:DebugPanelView;
		private var _background:Shape;
		
		public static const VIDEO_WIDTH:Number = 640;
		public static const VIDEO_HEIGHT:Number = 360;
		
		public function BaseVideoView()
		{
			super();

			addEventListener(Event.ADDED_TO_STAGE, onAddedToStage);
			addEventListener(Event.REMOVED_FROM_STAGE, onRemovedFromStage);
		}
		
		public function get background():Shape
		{
			return _background;
		}

		public function get console():DebugPanelView
		{
			return _console;
		}

		public function get spinnerView():SpinnerView
		{
			return _spinnerView;
		}

		public function get posterFrameButton():PosterFramePlayButton
		{
			return _posterFrameButton;
		}

		public function get controlBar():ControlBar
		{
			return _controlBar;
		}

		public function get mediaPlayerSprite():MediaPlayerSprite
		{
			return _mediaPlayerSprite;
		}

		protected function destroy():void
		{			
			removeChild(_mediaPlayerSprite);
			_mediaPlayerSprite = null;
			
			removeChild(_controlBar);
			_controlBar = null;
			
			removeChild(_posterFrameButton);
			_posterFrameButton = null;
			
			removeChild(_spinnerView);
			_spinnerView = null;
			
			removeChild(_console);
			_console = null;			
		}
		
		protected function onAddedToStage(event:Event):void
		{
			removeEventListener(Event.ADDED_TO_STAGE, onAddedToStage);
			
			addBackgroundPanel();
			addMediaPlayerSprite();
			addPosterFrameButton();
			addControlBar();
			addBusySpinner();
			addDebugPanel();
		}
				
		protected function onRemovedFromStage(event:Event):void
		{
			removeEventListener(Event.REMOVED_FROM_STAGE, onRemovedFromStage);
			
			destroy();
		}
		
		protected function addBackgroundPanel():void
		{
			_background = getBackground();
			addChild(_background);
		}
		
		protected function getBackground():Shape
		{
			var shape:Shape = new Shape();
			shape.graphics.beginFill(0x333333, 1);
			shape.graphics.drawRect(0, 0, VIDEO_WIDTH, stage.stageHeight);
			shape.graphics.endFill();
			return shape;
		}
		
		protected function addMediaPlayerSprite():void
		{
			_mediaPlayerSprite = new MediaPlayerSprite();
			_mediaPlayerSprite.scaleMode = ScaleMode.LETTERBOX;
			_mediaPlayerSprite.width = stage.stageWidth;
			_mediaPlayerSprite.height = stage.stageHeight;
			addChild(_mediaPlayerSprite);
		}
		
		protected function addControlBar():void
		{
			_controlBar = getControlBar();
			_controlBar.y = VIDEO_HEIGHT;
			addChild(_controlBar);
		}
		
		protected function getControlBar():ControlBar
		{
			var controlBar:ControlBar = new ControlBar();
			
			controlBar.width = VIDEO_WIDTH;
			controlBar.height = 30;
			controlBar.controlBarBackgroundColor = 0x000000;
			controlBar.addControls([new PlayPauseButton, new ScrubBar, new DualTimeCodeDisplay, new VolumeControl, new FullscreenButton]);
			
			return controlBar;
		}
		
		protected function addBusySpinner():void
		{
			_spinnerView = new SpinnerView();
			_spinnerView.visible = false;
			centerDisplayObject(_spinnerView);
			addChild(_spinnerView);
		}
		
		protected function addPosterFrameButton():void
		{
			_posterFrameButton = new PosterFramePlayButton(VIDEO_WIDTH, VIDEO_HEIGHT, 100);
			centerDisplayObject(_posterFrameButton);
			addChild(_posterFrameButton);
		}
		
		protected function addDebugPanel():void
		{
			_console = new DebugPanelView(VIDEO_WIDTH, VIDEO_HEIGHT);
			_console.visible = false;
			addChild(_console);
		}
		
		private function centerDisplayObject(displayObject:DisplayObject):void
		{
			displayObject.x = (VIDEO_WIDTH / 2);
			displayObject.y = (VIDEO_HEIGHT / 2);
		}
	}
}
