/*****************************************************
*  
*  Copyright 2010 Akamai Technologies, Inc.  All Rights Reserved.
*  
*****************************************************
*  The contents of this file are subject to the Mozilla Public License
*  Version 1.1 (the "License"); you may not use this file except in
*  compliance with the License. You may obtain a copy of the License at
*  http://www.mozilla.org/MPL/
*   
*  Software distributed under the License is distributed on an "AS IS"
*  basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
*  License for the specific language governing rights and limitations
*  under the License.
*   
*  
*  The Initial Developer of the Original Code is Akamai Technologies, Inc.
*  Portions created by Akamai Technologies, Inc. are Copyright (C) 2010 Akamai 
*  Technologies, Inc. All Rights Reserved. 
*  
*****************************************************/
package com.akamai.osmf.samples.event
{
	import flash.events.Event;
		
	public class PlaybackOptionsChangeEvent extends Event
	{
		/**
		 * Dispatched when the autoPlay property changes.
		 * The data property will contain a Boolean
		 * specifying true or false.
		 **/
		public static const AUTO_PLAY:String = "autoPlay";
		
		/**
		 * Dispatched when the autoRewind property changes.
		 * The data property will contain a Boolean
		 * specifying true or false.
		 **/
		public static const AUTO_REWIND:String = "autoRewind";
		
		/**
		 * Dispatched when the loop property changes.
		 * The data property will contain a Boolean
		 * specifying true or false.
		 **/
		public static const LOOP:String = "loop";
		
		/**
		 * Dispatched when the start sub-clip property changes.
		 * The data property will contain a Number specifying
		 * the media should begin play at this offset.
		 */
		public static const SUBCLIP_START:String = "subClipStart";
		
		/**
		 * Dispatched when the end sub-clip property changes.
		 * The data property will contain a Number specifying
		 * the media should end play at this offset.
		 **/
		public static const SUBCLIP_END:String = "subClipEnd";
		
		/**
		 * Dispatched when the useNetSession property changes.
		 * The data property will contain a String
		 * specifying one of the constants:
		 * AkamaiNetSessionType.NETSESSION_USAGE_OPPORTUNISTIC or 
		 * AkamaiNetSessionType.NETSESSION_USAGE_NEVER
		 **/
		public static const NETSESSION_MODE:String = "netSessionMode";
		
		/**
		 * Dispatched when the user specifies auth parameters.
		 * The data property will contain the following:
		 * <ul>
		 * <li> data.authParams:String - the auth params string</li>
		 * <li> data.connection:Boolean - true if this is a connection-level auth token</li>
		 * <li> data.stream:Boolean - true if this is a stream-level auth token</li>
		 * </ul>
		 **/
		public static const USE_AUTH_PARAMS:String = "useAuthParams";
		
		/**
		 * Dispatched when the user specifies manual switching should
		 * be used for dynamic streaming content.
		 **/
		public static const USE_MANUAL_SWITCHING:String = "useManualSwitching";
		
		/**
		 * Dispatched when the user specifies a max index value for 
		 * dynamic switching.
		 **/
		public static const MAX_ALLOWED_INDEX:String = "maxAllowedIndex";
		
		/**
		 * Dispatched when the user specifies a starting index value for
		 * dynamic switching.
		 **/
		public static const STARTING_INDEX:String = "startingIndex";
		
		/**
		 * Dispatched when the user specifies a starting bitrate value for
		 * dynamic switching.
		 **/
		public static const STARTING_BITRATE:String = "startingBitrate";
		
		/**
		 * Dispatched if the user chose OK from the authentication view.
		 * The data property will contain the following:
		 * <ul>
		 * <li> data.username:String</li>
		 * <li> data.password:String</li>
		 * </ul>
		 **/
		public static const AUTH_VIEW_OK:String = "authViewOK";
		
		/**
		 * Dispatched if the user chose CANCEL from the authentication view.
		 **/
		public static const AUTH_VIEW_CANCEL:String = "authViewCancel";
		
		/**
		 * Dispatched when the user specifies an interval for the starting
		 * bandwith estimate.
		 **/
		public static const BANDWITH_ESTIMATE_INTERVAL:String = "bandwidthEstimateInterval";
		
		/**
		 * Dispatched when the user selects/deselects the option for large buffers.
 		 * The data property will contain a Boolean
		 * specifying true or false.
		 **/
		public static const ENABLE_LARGE_BUFFERS:String = "enableLargeBuffers";
		
		/**
		 * Dispatched when the user specifies a number of fragment retry attempts
		 * for lost connectivity.  The data property will contain a Number.
		 **/
		public static const FRAG_RETRY_ATTEMPTS_FOR_LOST_CONNECTIVITY:String = "fragRetryAttemptsForLostConnectivity";
		
		/**
		 * Dispatched when the user selects/de-selects the option to show
		 * time in UTC time for live or live archived streams.
		 * The data property will contain a Boolean.
		 **/
		public static const SHOW_ABSOLUTE_TIME:String = "showAbsoluteTime";
		
		/**
		 * Dispatched when the user selects/de-selects the option to ask
		 * the Akamai plugin to ignore the streaming URL.
		 * The data property will contain a boolean.
		 **/
		public static const AKAMAI_PLUGIN_IGNORE_RESOURCE:String = "akamaiPluginIgnoreStream";
		
		/**
		 * Dispatched when the user selects/de-selects the option to 
		 * specify that an HDN1 or FMS resource is specified using
		 * an F4M manifest.
		 **/
		public static const USING_F4M_RESOURCE_FOR_NON_HDS:String = "usingF4MResourceForNonHDS";
		
		/**
		 * Dispatched when the user supplies a token for a DRM
		 * protected stream such as Flash Access. The data property
		 * will contain the token as a string.
		 **/
		public static const DRM_TOKEN:String = "drmToken";
		
		/**
		 * Dispatched when the user supplies a token for edge auth for
		 * HDN1 known as a primary token.
		 **/
		public static const PRIMARY_TOKEN:String = "primaryToken";
		
		/**
		 * Dispatched when the user checks the ASM or EUM checkboxes under
		 * the HDS tab. The data property will contain an object VO with keys asm and eum. 
		 * These keys value will reflect the state of the corresponding checkbox.
		 **/
		public static const USE_ASM_EUM:String = "qosEnabled";

		
		private var _data:Object;
		
		public function PlaybackOptionsChangeEvent(type:String, bubbles:Boolean=false, cancelable:Boolean=false, data:Object=null)
		{
			super(type, bubbles, cancelable);
			_data = data;
		}
		
		public function get data():Object
		{
			return _data;
		}
		
		override public function clone():Event
		{
			return new MediaLoadEvent(type, bubbles, cancelable, data);
		}
	}
}
